@@ -2,7 +2,7 @@ import datetime
 import xml.etree.ElementTree as ET
 from typing import List, Tuple
 
-import pandas
+import pandas  # type: ignore
 import requests
 
 from investments.currency import Currency
@@ -10,7 +10,7 @@ from investments.data_providers.cache import DataFrameCache
 from investments.money import Money
 
 
-class ExchangeRatesRUB(object):
+class ExchangeRatesRUB:
     def __init__(self, year_from: int = 2000, cache_dir: str = None):
         cache = DataFrameCache(cache_dir, f'cbrates_since{year_from}.cache', datetime.timedelta(days=1))
         df = cache.get()
